[![Codestyle](https://github.com/Tert0/fastapi-framework/actions/workflows/codestyle.yaml/badge.svg)](https://github.com/Tert0/fastapi-framework/actions/workflows/codestyle.yaml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Maintainability](https://api.codeclimate.com/v1/badges/27632fc7d85112fbdeaa/maintainability)](https://codeclimate.com/github/Tert0/fastapi-framework/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/27632fc7d85112fbdeaa/test_coverage)](https://codeclimate.com/github/Tert0/fastapi-framework/test_coverage)
[![PyPI version](https://badge.fury.io/py/fastapi-framework.svg)](https://badge.fury.io/py/fastapi-framework)
[![PyPI Downloads](https://img.shields.io/pypi/dm/fastapi-framework.svg)](https://pypi.org/project/fastapi-framework)


A FastAPI Framework for things like `Database`,
`Redis`, `Logging`, `JWT Authentication` and `Rate Limits` 

# Install

You can install this Library with:

```shell
pip install fastapi-framework
```

# Documentation

For the Documentation click [here](https://tert0.github.io/fastapi-framework)

# Features
- ✅ Database
- ✅ Redis
- ✅ Redis Publish/Subscribe
- ✅ FastAPI JWT
- ❌ FastAPI Permission System (for routes)
- ✅ Rate Limits
- ✅ Config Parser


# License

This Project is Licensed under the [MIT License](https://mit-license.org/)
